'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactBootstrap = require('react-bootstrap');

var _SidePanel = require('./SidePanel.scss');

var _SidePanel2 = _interopRequireDefault(_SidePanel);

var _Icon = require('../Icon');

var _Icon2 = _interopRequireDefault(_Icon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable jsx-a11y/href-no-hash */

/**
 * This component aims to display links as a menu.
 * @param {object} props react props
 *
 @example
 const actions = [
	 { label: 'Preparations', icon: 'fa fa-asterisk', onClick: action('Preparations clicked') },
	 { label: 'Datasets', icon: 'fa fa-file-excel-o', onClick: action('Datasets clicked') },
	 { label: 'Favorites', icon: 'fa fa-star', onClick: action('Favorites clicked') }
 ];
 <SidePanel
	 actions={ actions }
	 onToggleDock={ action('Toggle dock clicked') }
	 docked={ isDocked }
 />
 *
 */
function SidePanel(props) {
	var actions = props.actions || [];

	var dockedCSS = _defineProperty({}, _SidePanel2.default.docked, props.docked);
	var navCSS = (0, _classnames2.default)(_SidePanel2.default['tc-side-panel'], dockedCSS, 'tc-side-panel');
	var listCSS = (0, _classnames2.default)('nav nav-pills nav-inverse nav-stacked', 'tc-side-panel-list', _SidePanel2.default['action-list']);

	return _react2.default.createElement(
		'nav',
		{ className: navCSS },
		_react2.default.createElement(
			'ul',
			{ className: listCSS },
			_react2.default.createElement(
				'li',
				{ className: 'tc-side-panel-list-item' },
				_react2.default.createElement(
					_reactBootstrap.Button,
					{
						id: props.id && props.id + '-toggle-dock',
						className: (0, _classnames2.default)(_SidePanel2.default['toggle-btn'], _SidePanel2.default.link),
						bsStyle: 'link',
						onClick: props.onToggleDock,
						'aria-hidden': 'true',
						title: 'Toggle side panel'
					},
					_react2.default.createElement(_Icon2.default, { name: 'talend-arrow-left' })
				)
			),
			actions.map(function (action) {
				return _react2.default.createElement(
					'li',
					{
						key: action.label,
						className: (0, _classnames2.default)('tc-side-panel-list-item', { active: !!action.active })
					},
					_react2.default.createElement(
						_reactBootstrap.Button,
						{
							id: props.id && props.id + '-nav-' + action.label.toLowerCase().split(' ').join('-'),
							title: 'Display ' + action.label,
							bsStyle: 'link',
							role: 'link',
							className: _SidePanel2.default.link,
							onClick: action.onClick
						},
						action.icon ? _react2.default.createElement(_Icon2.default, { name: action.icon }) : null,
						props.docked ? null : _react2.default.createElement(
							'span',
							null,
							action.label
						)
					)
				);
			})
		)
	);
}

SidePanel.propTypes = {
	id: _react2.default.PropTypes.string,
	actions: _react2.default.PropTypes.arrayOf(_react2.default.PropTypes.shape({
		label: _react2.default.PropTypes.string,
		icon: _react2.default.PropTypes.string,
		onClick: _react2.default.PropTypes.func
	})),
	onToggleDock: _react2.default.PropTypes.func,
	docked: _react2.default.PropTypes.bool
};

exports.default = SidePanel;